@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 import logging
 
 from django.contrib.auth.signals import user_logged_in
@@ -8,8 +10,6 @@ from django.dispatch import receiver
 from django.dispatch import Signal
 from django.utils import timezone
 
-from ipware.ip import get_ip
-
 from axes.conf import settings
 from axes.attempts import get_cache_key
 from axes.attempts import get_cache_timeout
@@ -19,7 +19,7 @@ from axes.attempts import ip_in_whitelist
 from axes.models import AccessLog, AccessAttempt
 from axes.utils import get_client_str
 from axes.utils import query2str
-from axes.utils import get_axes_cache
+from axes.utils import get_axes_cache, get_client_ip
 
 
 log = logging.getLogger(settings.AXES_LOGGER)
@@ -29,14 +29,14 @@ user_locked_out = Signal(providing_args=['request', 'username', 'ip_address'])
 
 
 @receiver(user_login_failed)
-def log_user_login_failed(sender, credentials, request, **kwargs):
+def log_user_login_failed(sender, credentials, request, **kwargs):  # pylint: disable=unused-argument
     """ Create an AccessAttempt record if the login wasn't successful
     """
     if request is None or settings.AXES_USERNAME_FORM_FIELD not in credentials:
-        log.error('Attempt to authenticate with a custom backend failed.')
+        log.warning('Attempt to authenticate with a custom backend failed.')
         return
 
-    ip_address = get_ip(request)
+    ip_address = get_client_ip(request)
     username = credentials[settings.AXES_USERNAME_FORM_FIELD]
     user_agent = request.META.get('HTTP_USER_AGENT', '<unknown>')[:255]
     path_info = request.META.get('PATH_INFO', '<unknown>')[:255]
@@ -62,7 +62,7 @@ def log_user_login_failed(sender, credentials, request, **kwargs):
     get_axes_cache().set(cache_hash_key, failures, cache_timeout)
 
     # has already attempted, update the info
-    if len(attempts):
+    if attempts:
         for attempt in attempts:
             attempt.get_data = '%s\n---------\n%s' % (
                 attempt.get_data,
@@ -78,13 +78,12 @@ def log_user_login_failed(sender, credentials, request, **kwargs):
             attempt.attempt_time = timezone.now()
             attempt.save()
 
-            fail_msg = 'AXES: Repeated login failure by {0}.'.format(
-                get_client_str(username, ip_address, user_agent, path_info)
+            log.info(
+                'AXES: Repeated login failure by %s. Count = %d of %d',
+                get_client_str(username, ip_address, user_agent, path_info),
+                failures,
+                settings.AXES_FAILURE_LIMIT
             )
-            count_msg = 'Count = {0} of {1}'.format(
-                failures, settings.AXES_FAILURE_LIMIT
-            )
-            log.info('{0} {1}'.format(fail_msg, count_msg))
     else:
         # Record failed attempt. Whether or not the IP address or user agent is
         # used in counting failures is handled elsewhere, so we just record
@@ -101,9 +100,8 @@ def log_user_login_failed(sender, credentials, request, **kwargs):
         )
 
         log.info(
-            'AXES: New login failure by {0}. Creating access record.'.format(
-                get_client_str(username, ip_address, user_agent, path_info)
-            )
+            'AXES: New login failure by %s. Creating access record.',
+            get_client_str(username, ip_address, user_agent, path_info)
         )
 
     # no matter what, we want to lock them out if they're past the number of
@@ -113,9 +111,10 @@ def log_user_login_failed(sender, credentials, request, **kwargs):
         settings.AXES_LOCK_OUT_AT_FAILURE and
         is_user_lockable(request)
     ):
-        log.warning('AXES: locked out {0} after repeated login attempts.'.format(
+        log.warning(
+            'AXES: locked out %s after repeated login attempts.',
             get_client_str(username, ip_address, user_agent, path_info)
-        ))
+        )
 
         # send signal when someone is locked out.
         user_locked_out.send(
@@ -124,17 +123,18 @@ def log_user_login_failed(sender, credentials, request, **kwargs):
 
 
 @receiver(user_logged_in)
-def log_user_logged_in(sender, request, user, **kwargs):
+def log_user_logged_in(sender, request, user, **kwargs):  # pylint: disable=unused-argument
     """ When a user logs in, update the access log
     """
     username = user.get_username()
-    ip_address = get_ip(request)
+    ip_address = get_client_ip(request)
     user_agent = request.META.get('HTTP_USER_AGENT', '<unknown>')[:255]
     path_info = request.META.get('PATH_INFO', '<unknown>')[:255]
     http_accept = request.META.get('HTTP_ACCEPT', '<unknown>')[:1025]
-    log.info('AXES: Successful login by {0}.'.format(
+    log.info(
+        'AXES: Successful login by %s.',
         get_client_str(username, ip_address, user_agent, path_info)
-    ))
+    )
 
     if not settings.AXES_DISABLE_SUCCESS_ACCESS_LOG:
         AccessLog.objects.create(
@@ -148,10 +148,10 @@ def log_user_logged_in(sender, request, user, **kwargs):
 
 
 @receiver(user_logged_out)
-def log_user_logged_out(sender, request, user, **kwargs):
+def log_user_logged_out(sender, request, user, **kwargs):  # pylint: disable=unused-argument
     """ When a user logs out, update the access log
     """
-    log.info('AXES: Successful logout by {0}.'.format(user))
+    log.info('AXES: Successful logout by %s.', user)
 
     if user and not settings.AXES_DISABLE_ACCESS_LOG:
         AccessLog.objects.filter(
@@ -161,7 +161,7 @@ def log_user_logged_out(sender, request, user, **kwargs):
 
 
 @receiver(post_save, sender=AccessAttempt)
-def update_cache_after_save(instance, **kwargs):
+def update_cache_after_save(instance, **kwargs):  # pylint: disable=unused-argument
     cache_hash_key = get_cache_key(instance)
     if not get_axes_cache().get(cache_hash_key):
         cache_timeout = get_cache_timeout()
@@ -169,6 +169,6 @@ def update_cache_after_save(instance, **kwargs):
 
 
 @receiver(post_delete, sender=AccessAttempt)
-def delete_cache_after_delete(instance, **kwargs):
+def delete_cache_after_delete(instance, **kwargs):  # pylint: disable=unused-argument
     cache_hash_key = get_cache_key(instance)
     get_axes_cache().delete(cache_hash_key)
