@@ -1,4 +1,6 @@
-from .test_settings import *
+from __future__ import unicode_literals
+
+from .test_settings import *  # pylint: disable=unused-wildcard-import
 
 AXES_CACHE = 'axes'
 
